==> rdkit_202009.4.orig.tar.xz: rdkit-Release_2020_09_4/Code/GraphMol/FileParsers/XYZFileWriter.cpp <==
//  Copyright (C) 2019 Eisuke Kawashima
//
//   @@ All Rights Reserved @@
//  This file is part of the RDKit.
//  The contents are covered by the terms of the BSD license
//  which is included in the file license.txt, found at the root
//  of the RDKit source tree.
//

#include "FileParsers.h"
#include <fstream>
#include <sstream>
#include <boost/format.hpp>
#include <RDGeneral/BadFileException.h>

namespace RDKit {

std::string MolToXYZBlock(const ROMol& mol, int confId) {
  if (!mol.getNumConformers()) {
    BOOST_LOG(rdErrorLog)
        << "Cannot write molecules with no conformers to XYZ block\n";
    return "";
  }

  const auto& conf = mol.getConformer(confId);
  const unsigned int nAtoms = mol.getNumAtoms();

  std::stringstream ss;
  ss << nAtoms << '\n';

  std::string name;
  if (mol.getPropIfPresent(common_properties::_Name, name)) {
    ss << name.substr(0, name.find_first_of('\n'));
  }
  ss << '\n';

  for (unsigned int i = 0; i < nAtoms; i++) {
    const auto& symbol = mol.getAtomWithIdx(i)->getSymbol();
    const auto& pos = conf.getAtomPos(i);
    ss << boost::format{"%-3s %11.6f %11.6f %11.6f\n"} % symbol % pos.x % pos.y % pos.z;
  }
  return ss.str();
}

void MolToXYZFile(const ROMol& mol, const std::string& fName, int confId) {
  std::ofstream outStream(fName);
  if (!outStream) {
    std::ostringstream errout;
    errout << "Bad output file " << fName;
    throw BadFileException(errout.str());
  }
  outStream << MolToXYZBlock(mol, confId);
}

}  // namespace RDKit

==> rdkit_202309.3.orig.tar.xz: rdkit-Release_2023_09_3/Code/GraphMol/FileParsers/XYZFileWriter.cpp <==
//  Copyright (C) 2019 Eisuke Kawashima
//
//   @@ All Rights Reserved @@
//  This file is part of the RDKit.
//  The contents are covered by the terms of the BSD license
//  which is included in the file license.txt, found at the root
//  of the RDKit source tree.
//

#include "FileParsers.h"
#include <fstream>
#include <sstream>
#include <boost/format.hpp>
#include <RDGeneral/BadFileException.h>

namespace RDKit {

std::string MolToXYZBlock(const ROMol& mol, int confId) {
  if (!mol.getNumConformers()) {
    BOOST_LOG(rdErrorLog)
        << "Cannot write molecules with no conformers to XYZ block\n";
    return "";
  }

  const auto& conf = mol.getConformer(confId);
  const unsigned int nAtoms = mol.getNumAtoms();

  std::stringstream ss;
  ss << nAtoms << '\n';

  std::string name;
  if (mol.getPropIfPresent(common_properties::_Name, name)) {
    ss << name.substr(0, name.find_first_of('\n'));
  }
  ss << '\n';

  for (unsigned int i = 0; i < nAtoms; i++) {
    const auto& symbol = mol.getAtomWithIdx(i)->getSymbol();
    const auto& pos = conf.getAtomPos(i);
    ss << boost::format{"%-3s %11.6f %11.6f %11.6f\n"} % symbol % pos.x %
              pos.y % pos.z;
  }
  return ss.str();
}

void MolToXYZFile(const ROMol& mol, const std::string& fName, int confId) {
  std::ofstream outStream(fName);
  if (!outStream) {
    std::ostringstream errout;
    errout << "Bad output file " << fName;
    throw BadFileException(errout.str());
  }
  outStream << MolToXYZBlock(mol, confId);
}

}  // namespace RDKit
